@@ -1,13 +1,13 @@
 package Sys::Info;
+$Sys::Info::VERSION = '0.7811';
 use strict;
 use warnings;
-use vars qw( $VERSION @EXPORT_OK );
-use Carp qw( croak    );
+
+use Carp qw( croak );
 use Sys::Info::Constants qw( OSID );
 use base qw( Sys::Info::Base );
 
-$VERSION = '0.78';
-@EXPORT_OK = qw( OSID );
+our @EXPORT_OK = qw( OSID );
 
 __PACKAGE__->_mk_object( $_ ) for qw( OS Device );
 
@@ -93,9 +93,17 @@ sub _legacy_perl { # function
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info - Fetch information from the host system
+Sys::Info
+
+=head1 VERSION
+
+version 0.7811
 
 =head1 SYNOPSIS
 
@@ -112,11 +120,12 @@ Sys::Info - Fetch information from the host system
 
 =head1 DESCRIPTION
 
-This document describes version C<0.78> of C<Sys::Info>
-released on C<17 April 2011>.
-
 Extracts and collects information from the host system.
 
+=head1 NAME
+
+Sys::Info - Fetch information from the host system
+
 =head1 METHODS
 
 =head2 new
@@ -190,16 +199,13 @@ L<Win32::TieRegistry>
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2011 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
